.TL main
version 3.6
.LP
.SH 1 DRAWTREE and DRAWGRAM.LP
.LP © Copyright 1986-2002 by The University of Washington. Written by
Joseph Felsenstein. Permission is granted to copy this document
provided that no fee is charged for it and that this copyright notice
is not removed..LP DRAWTREE and DRAWGRAM are interactive tree-plotting
programs that take a tree description in a file and read it, and then
let you interactively make various settings and then plot the tree on
a laser printer, plotter, or dot matrix printer. In many cases (with
Macintosh or PC graphics, with X windows, or with a
Tektronix-compatible graphics terminal) you can preview the resulting
tree. This allows you to modify the tree until you like the result,
then plot the result. DRAWTREE plots unrooted trees and DRAWGRAM plots
rooted cladograms and phenograms. On good laser printers or as files
for good drawing programs both can produce fully publishable results.
On dot matrix printers the results look grainy but are good enough for
overhead transparencies or slides for presentations..LP These programs
are descended from PLOTGRAM and PLOTREE written by Christopher
Meacham. I have incorporated his code for fonts and his plotter
drivers, and in DRAWTREE have used some of his code for drawing
unrooted trees. In both programs I have also included some plotter
driver code by David Swofford, Julian Humphries and George D.F."Buz"
Wilson, to all of whom I am very grateful. Mostly, however, they
consist of my own code and that of my programmers. The font files are
printable-character recodings of the public-domain Hershey fonts,
recoded by Christopher Meacham..LP This document will describe the
features common to both programs. The documents for DRAWTREE and
DRAWGRAM describe the particular choices you can make in each of those
programs. The Appendix to this documentation file contains some pieces
of C code that can be inserted to make the program handle another
plotting device -- the plotters by Calcomp..LP.SH 2 A Short
Introduction.LP.LP To use DRAWTREE and DRAWGRAM, you must have.LP.RS
.IP"(1) The compiled version of the program. If you have not obtained
a" version of PHYLIP precompiled for your machine, you will have to
take the source code given here and modify it for your C compiler and
then compile it. This is not too hard: it is discussed below..LP.IP
"(2) A tree file. Trees are described in the nested-parenthesis
notation" used throughout PHYLIP and standardized in an informal
meeting of program authors in Durham, New Hampshire in June, 1986.
Trees for both programs may be either bifurcating or multifurcating,
and may either have or not have branch lengths. Tree files produced by
the PHYLIP programs are in this form. There is further description of
the tree file format later in this document..LP.IP"(3) A font file.
There are six font files distributed with PHYLIP:" these consist of
three Roman, two Italic, and one Russian Cyrillic font, all from the
public-domain Hershey Fonts, in ASCII readable form. The details of
font representation need not concern you; all you need to do is to
copy the font file corresponding to the font you want into the
appropriate directory under the appropriate file name, and let the
program use it. Or you can let the program ask you for the name of the
font file, which it will do if it does not find one itself. The six
fonts are, respectively, a one- and a two-stroke sans-serif Roman
font, a three-stroke serifed Roman font, a two- and a three- stroke
serifed Italic font, and a two-stroke Cyrillic font for the Russian
language. If this is not clear just try them all. Note that for some
printers several built-in fonts such as Times-Roman and Courier can be
used too..LP.IP"(4) A plotting device, and if possible a screen on
which you can preview" the plot. The programs work with
Postscript-compatible laser printers, laser printers compatible with
the PCL printer language of the Hewlett-Packard Laserjet series, IBM
PC graphics screens, the PICT format for the MacDraw drawing program,
the PCX file format for the PC Paintbrush painting program, the file
format for the freeware X-windows drawing programs \f(CWxfig\fR and
\f(CWidraw\fR, the X Bitmap format for X-windows, plotters including
Hewlett-Packard models, dot matrix printers including models by Epson
and Apple, graphics terminals from DEC and Tektronix, the input format
for the freeware ray-tracing (3-dimensional rendering) programs
\f(CWPOV\fR and \f(CWrayshade\fR, and, strangest and most wonderful of
all, the Virtual Reality Markup Language (VRML) which is a file format
that is used by freely-available virtual reality programs like Cosmo
Player. You can choose the plotting and previewing devices from a menu
at run time, and these can be different. There are places in the
source code for the program where you can insert code for a new
plotter, should you want to do that..RE.LP Once you have all these,
the programs should be fairly self explanatory, particular if you can
preview your plots so that you can discover the meaning of the
different options by trying them out..LP Once you have a compiled
version of the appropriate program, say DRAWGRAM, and a file called
(say) \f(CWtreefile\fR with the tree in it, and a font file (say
\f(CWfont2\fR which you have copied as a file called
\f(CWfontfile\fR), all you do is run the program DRAWGRAM. It should
automatically read the font and tree files, and will allow you to
change the graphics devices. Then it will let you see the options it
has chosen, and ask you if you want to change these. Once you have
modified those that you want to, you can tell it to accept those. The
program will then allow you to preview the tree on your screen, if you
have told it that you have an appropriate graphics screen. After
previewing the tree, the program will want to know whether you are
ready to plot the tree. In Windows you answer this using the File menu
of the preview window. In X Windows and Macintosh systems you can
close the preview window by clicking on its corner. Whether or not you
close it, if you get back to the text window that had the menus, and
it accepts typing in that window, you will be asked whether you want
to accept the plot as is. If you say no, it will once again allow you
to change options and will the allow you to preview the tree again,
and so on as many times as you want. If you say yes, then it will
write a file called (say) \f(CWplotfile\fR. If you then copy this file
to your printer or plotter, it should result in a beautifully plotted
tree. If the final plotting device is a Macintosh or PC graphics
screen, it may not write a plot file but will plot directly on the
screen..LP Having read the above, you may be ready to run the program.
Below you Will find more information about representation of trees in
the tree file, on the different kinds of graphics devices supported by
this program, and on how to recompile these programs..LP.SH 2 Trees.LP
.LP The Newick Standard for representing trees in computer-readable
form makes use of the correspondence between trees and nested
parentheses, noticed in 1857 by the famous English mathematician
Arthur Cayley. If we have this rooted tree:.LP.DS L A D \ E / \ C / /
\! / / \! / / B \!/ / \ o / \! / \! / \! / \! / \!/ o!!.DE.LP then in
the tree file it is represented by the following sequence of printable
characters, starting at the beginning of the file:.LP (B,(A,C,E),D);
.LP The tree ends with a semicolon. Everything after the semicolon in
the input file is ignored, including any other trees. The bottommost
node in the tree is an interior node, not a tip. Interior nodes are
represented by a pair of matched parentheses. Between them are
representations of the nodes that are immediately descended from that
node, separated by commas. In the above tree, the immediate
descendants are B, another interior node, and D. The other interior
node is represented by a pair of parentheses, enclosing
representations of its immediate descendants, A, C, and E..LP Tips are
represented by their names. A name can be any string of printable
characters except blanks, colons, semcolons, parentheses, and square
brackets. In the programs a maximum of 20 characters are allowed for
names: this limit can easily be increased by recompiling the program
and changing the constant declaration for"MAXNCH" in \f(CWphylip.h\fR.
.LP Because you may want to include a blank in a name, it is assumed
that an underscore character ("_") stands for a blank; any of these in
a name will be converted to a blank when it is read in. Any name may
also be empty: a tree like.LP (,(,,),);.LP is allowed. Trees can be
multifurcating at any level (while in many of the programs
multifurcations of user-defined trees are not allowed or restricted to
a trifurcation at the bottommost level, these programs do make any
such restriction)..LP Branch lengths can be incorporated into a tree
by putting a real number, with or without decimal point, after a node
and preceded by a colon. This represents the length of the branch
immediately below that node. Thus the above tree might have lengths
represented as:.LP (B:6.0,(A:5.0,C:3.0,E:4.0):5.0,D:11.0);.LP These
programs will be able to make use of this information only if lengths
exist for every branch, except the one at the bottom of the tree..LP
The tree starts on the first line of the file, and can continue to
subsequent lines. It is best to proceed to a new line, if at all,
immediately after a comma. Blanks can be inserted at any point except
in the middle of a species name or a branch length..LP The above
description is of a subset of the Newick Standard. For example,
interior nodes can have names in that standard, but if any are
included the present programs will omit them..LP To help you
understand this tree representation, here are some trees in the above
form:.LP.DS L
((raccoon:19.19959,bear:6.80041):0.84600,((sea_lion:11.99700,
seal:12.00300):7.52973,((monkey:100.85930,cat:47.14069):20.59201,
weasel:18.87953):2.09460):3.87382,dog:25.46154);.LP
(Bovine:0.69395,(Gibbon:0.36079,(Orang:0.33636,(Gorilla:0.17147,(Chimp:0.19268,
Human:0.11927):0.08386):0.06124):0.15057):0.54939,Mouse:1.21460);.LP
(Bovine:0.69395,(Hylobates:0.36079,(Pongo:0.33636,(G._Gorilla:0.17147,
(P._paniscus:0.19268,H._sapiens:0.11927):0.08386):0.06124):0.15057):0.54939,
Rodent:1.21460);.LP ();.LP ((A,B),(C,D));.LP
(Alpha,Beta,Gamma,Delta,,Epsilon,,,);.DE.LP The Newick Standard was
adopted June 26, 1986 by an informal committee meeting during the
Society for the Study of Evolution meetings in Durham, New Hampshire
and consisting of James Archie, William H.E. Day, Wayne Maddison,
Christopher Meacham, F. James Rohlf, David Swofford, and myself. A web
page describing it will be found at
http://evolution.gs.washington.edu/phylip/newicktree.html..LP.SH 2
Plotter file formats.LP.LP When the programs run they have a menu
which allows you to set (on its option P) the final plotting device,
and another menu which allows you to set the type of preview screen.
The choices for previewing are a subset of those available for
plotting, and they can be different (the most useful combination will
usually be a previewing graphics screen with a hard-copy plotter or a
drawing program graphics file format)..LP The plotting device menu
looks like this:.LP.TS center;.DS L type: to choose one compatible
with: L Postscript printer file format M PICT format (for drawing
programs) J HP Laserjet PCL file format W MS-Windows Bitmap F FIG 2.0
drawing program format A Idraw drawing program format Z VRML Virtual
Reality Markup Language file P PCX file format (for drawing programs)
K TeKtronix 4010 graphics terminal X X Bitmap format V POVRAY 3D
rendering program file R Rayshade 3D rendering program file H
Hewlett-Packard pen plotter (HPGL file format) D DEC ReGIS graphics
(VT240 terminal) E Epson MX-80 dot-matrix printer C
Prowriter/Imagewriter dot-matrix printer T Toshiba 24-pin dot-matrix
printer O Okidata dot-matrix printer B Houston Instruments plotter U
other: one you have inserted code for Choose one:.DE.TE.LP Here are
the choices, with some comments on each:.LP \fBPostscript printer file
format.\fR This means that the program will generate a file containing
Postscript commands as its plot file. This can be printed on any
Postscript-compatible laser printer. The page size is assumed to be
8.5 by 11 inches, but as plotting is within this limit A4 metric paper
should work well too. This is the best quality output option. For this
printer the menu options in DRAWGRAM and DRAWTREE that allow you to
select one of the built-in fonts will work. The programs default to
Times-Roman when this plotting option is in effect. I have been able
to use fonts Courier, Times-Roman, and Helvetica. The others have
eluded me for some reason known only to those who really understand
Postscript..LP If your laser printer, supposedly Postcript-compatible,
refuses to print the plot file, you might consider whether the first
line of the plot file, which starts with \f(CW%!\fR needs to be
altered somehow or eliminated. If your Laserwriter is hooked to a
Macintosh it will be necessary to persuade it to print the plot file.
In recent versions of the Macintosh operating systems this can
supposedly be done by dragging the file icon onto the printer icon on
the desktop. In earlier versions of the MacOS operating system you
might have to use a utility called the Laserwriter Font Utility, which
was distributed with the operating system..LP \fBPICT format (for
drawing programs).\fR This file format is read by many drawing
programs (an early example was MacDraw). It has support for some
fonts, though if fonts are used the species names can only be drawn
horizontally or vertically, not at other angles in between. The
control over line widths is a bit rough also, so that some lines at
different angles may turn out to be different widths when you do not
want them to be. If you are working on a Macintosh system and have not
been able to persuade it to print a Postscript file, this option may
be the best solution, as you could then read the file into a drawing
program and then order it to print the resulting screen. The PICT file
format has font support, and the default font for this plotting option
is set to Times. You can also choose font attributes for the labels
such as Bold, Italic, Outline, and Shadowed..LP \fBHP Laserjet PCL
file format.\fR Hewlett-Packard's extremely popular line of laser
printers has been emulated by many other brands of laser printer, so
that this format is compatible with more printers than any other. One
limitation of the PCL4 command language for these printers is that it
does not have primitive operations for drawing arbitrary diagonal
lines. This means that they must be treated by these programs as if
they were dot matrix printers with a great many dots. This makes
output files large, and output can be slow. The user will be asked to
choose the dot resoluton (75, 150, or 300 dots per inch). The 300 dot
per inch setting should not be used if the laser printer's memory is
less than 512k bytes. The quality of output is also not as good as it
might be so that the Postscript file format will usually produce
better results even at the same resolution. I am grateful to Kevin
Nixon for inadvertently pointing out that on Laserjets one does not
have to dump the complete bitmap of a page to plot a tree..LP
\fBMS-Windows Bitmap.\fR This file format is used by most Windows
drawing and paint programs, including Windows Paint which comes with
the Windows operating system. It asks you to choose the height and
width of the graphic image in pixels. For the moment, the image is set
to be a monochrome image which can only be black or white. We hope to
change that soon, but note that by pasting the image into a copy of
Paint that is set to have a color image of the appropriate size, one
can get a version whose color can be changed. Note also that Windows
Bitmap files can be used as"wallpaper" images for the background of a
desktop..LP \fBIBM PC graphics screens.\fR The code for this in the
programs is available in the precompiled PC executables or if you
compile the programs yourself in C. The graphics modes supported are
CGA, EGA, VGA, Hercules, and AT 0) { if (yrel> 0) quadrant ='P'; else
quadrant ='T';} else if (yrel> 0) quadrant ='X'; else quadrant ='1';
xrel = labs(xrel); yrel = labs(yrel); if (xrel> yrel) n = xrel / 255 +
1; else n = yrel / 255 + 1; xinc = xrel / n; yinc = yrel / n; xlast =
xrel % n; ylast = yrel % n; xhigh = xinc / 16; yhigh = yinc / 16; xlow
= xinc & 15; ylow = yinc & 15; for (i = 1; i < = n; i++)
fprintf(plotfile,"%c%c%c%c%c", quadrant, cchex[xhigh - 1], cchex[xlow
- 1], cchex[yhigh - 1], cchex[ylow - 1]); if (xlast!= 0 || ylast!= 0)
fprintf(plotfile,"%c%c%c%c%c", quadrant, cchex[-1], cchex[xlast - 1],
cchex[-1], cchex[ylast - 1]); break;.DE.LP Code to be inserted into
function initplotter:.LP.DS L case other: cchex[-1] ='C'; cchex[0] =
'D'; cchex[1] ='H'; cchex[2] ='L'; cchex[3] ='P'; cchex[4] ='T';
cchex[5] ='X'; cchex[6] ='1'; cchex[7] ='5'; cchex[8] ='9'; cchex[9] =
'/'; cchex[10] ='='; cchex[11] ='#'; cchex[12] ='"'; cchex[13] ='\'';
cchex[14] ='^'; xnow = 0.0; ynow = 0.0; fprintf(plotfile,
"CCCCCCCCCC"); break;.DE.LP Code to be inserted into function
finishplotter:.LP.DS L case other: plot(penup, 0.0, yrange + 50.0);
break;.DE
